==> 0.6.6b1.zip: dmdirc-client/src/com/dmdirc/updater/components/LauncherComponent.java <==
/*
 * Copyright (c) 2006-2011 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.updater.components;

import com.dmdirc.updater.OptionsComponent;
import com.dmdirc.updater.UpdateChecker;
import com.dmdirc.updater.UpdateComponent;
import com.dmdirc.updater.Version;
import com.dmdirc.util.resourcemanager.ZipResourceManager;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;

/**
 * Component for updates of DMDirc's launcher.
 */
public class LauncherComponent implements UpdateComponent, OptionsComponent {

    /** The platform of our current launcher. */
    private static String platform = "";

    /** The version of our current launcher. */
    private static Version version = new Version();

    /** The options of our current launcher. */
    private static String[] options = new String[]{};

    /**
     * Parses the specified launcher information.
     *
     * @param info The platform and version of the launcher, separated by '-'.
     */
    public static void setLauncherInfo(final String info) {
        final int hpos = info.indexOf('-');
        final int cpos = info.indexOf(',');

        if (hpos == -1) {
            return;
        }

        platform = info.substring(0, hpos);
        if (cpos == -1) {
            version = new Version(info.substring(hpos + 1));
        } else {
            version = new Version(info.substring(hpos + 1, cpos));
            options = info.substring(cpos + 1).split(",");
        }

        UpdateChecker.registerComponent(new LauncherComponent());
    }

    /**
     * Determines if the client has been run using the launcher.
     *
     * @return True if the launcher has been used, false otherwise
     */
    public static boolean isUsingLauncher() {
        return version.isValid();
    }

    /** {@inheritDoc} */
    @Override
    public String getName() {
        return "launcher-" + platform;
    }

    /** {@inheritDoc} */
    @Override
    public String getFriendlyName() {
        return "Launcher";
    }

    /** {@inheritDoc} */
    @Override
    public String getFriendlyVersion() {
        return String.valueOf(getVersion());
    }

    /** {@inheritDoc} */
    @Override
    public Version getVersion() {
        return version;
    }

    /** {@inheritDoc} */
    @Override
    public String[] getOptions() {
        return Arrays.copyOf(options, options.length);
    }


    /** {@inheritDoc} */
    @Override
    public boolean requiresRestart() {
        return true;
    }

    /** {@inheritDoc} */
    @Override
    public boolean requiresManualInstall() {
        return false;
    }

    /** {@inheritDoc} */
    @Override
    public String getManualInstructions(final String path) {
        return "";
    }

    /** {@inheritDoc} */
    @Override
    public boolean doInstall(final String path) throws IOException {
        final File tmpFile = new File(path);
        if (platform.equalsIgnoreCase("Linux")
                || platform.equalsIgnoreCase("unix")) {
            final File targetFile = new File(tmpFile.getParent()
                    + File.separator + ".launcher.sh");

            if (targetFile.exists()) {
                targetFile.delete();
            }

            tmpFile.renameTo(targetFile);
            targetFile.setExecutable(true);

        } else {
            ZipResourceManager.getInstance(path).extractResources("",
                    tmpFile.getParent() + File.separator);
            new File(path).delete();
        }
        return true;
    }

}

==> 0.6.7.zip: dmdirc-client/src/com/dmdirc/updater/components/LauncherComponent.java <==
/*
 * Copyright (c) 2006-2012 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.updater.components;

import com.dmdirc.updater.UpdateChecker;
import com.dmdirc.updater.UpdateComponent;
import com.dmdirc.updater.Version;
import com.dmdirc.util.resourcemanager.ZipResourceManager;

import java.io.File;
import java.io.IOException;

/**
 * Component for updates of DMDirc's launcher.
 */
public class LauncherComponent implements UpdateComponent {

    /** The platform of our current launcher. */
    private static String platform = "";

    /** The version of our current launcher. */
    private static Version version = new Version();

    /**
     * Parses the specified launcher information.
     *
     * @param info The platform and version of the launcher, separated by '-'.
     */
    public static void setLauncherInfo(final String info) {
        final int hpos = info.indexOf('-');
        final int cpos = info.indexOf(',');

        if (hpos == -1) {
            return;
        }

        platform = info.substring(0, hpos);
        if (cpos == -1) {
            version = new Version(info.substring(hpos + 1));
        } else {
            version = new Version(info.substring(hpos + 1, cpos));
        }

        UpdateChecker.getManager().addComponent(new LauncherComponent());
    }

    /**
     * Determines if the client has been run using the launcher.
     *
     * @return True if the launcher has been used, false otherwise
     */
    public static boolean isUsingLauncher() {
        return version.isValid();
    }

    /** {@inheritDoc} */
    @Override
    public String getName() {
        return "launcher-" + platform;
    }

    /** {@inheritDoc} */
    @Override
    public String getFriendlyName() {
        return "Launcher";
    }

    /** {@inheritDoc} */
    @Override
    public String getFriendlyVersion() {
        return String.valueOf(getVersion());
    }

    /** {@inheritDoc} */
    @Override
    public Version getVersion() {
        return version;
    }

    /** {@inheritDoc} */
    @Override
    public boolean requiresRestart() {
        return true;
    }

    /** {@inheritDoc} */
    @Override
    public boolean requiresManualInstall() {
        return false;
    }

    /** {@inheritDoc} */
    @Override
    public String getManualInstructions(final String path) {
        return "";
    }

    /** {@inheritDoc} */
    @Override
    public boolean doInstall(final String path) throws IOException {
        final File tmpFile = new File(path);
        if (platform.equalsIgnoreCase("Linux")
                || platform.equalsIgnoreCase("unix")) {
            final File targetFile = new File(tmpFile.getParent()
                    + File.separator + ".launcher.sh");

            if (targetFile.exists()) {
                targetFile.delete();
            }

            tmpFile.renameTo(targetFile);
            targetFile.setExecutable(true);

        } else {
            ZipResourceManager.getInstance(path).extractResources("",
                    tmpFile.getParent() + File.separator);
            new File(path).delete();
        }
        return true;
    }

}
